Test coverage report: miniblog.blogs.permissions

# miniblog.blogs.permissions: 2 total statements, 100.0% covered

Generated: Thu 2012-03-01 08:22 CST

Source file: /home/alisue/Dropbox/Codes/django-permission/tests/src/miniblog/blogs/permissions.py

Stats: 1 executed, 0 missed, 1 excluded, 34 ignored

1. `#!/usr/bin/env python`
2. `# vim: set fileencoding=utf-8 :`
3. `"""`
4. `short module explanation`
5. ``
6. ``
7. `AUTHOR:`
8. `lambdalisue[Ali su ae] (lambdalisue@hashnote.net)`
9. ``
10. `License:`
11. `The MIT License (MIT)`
12. ``
13. `Copyright (c) 2012 Alisue allright reserved.`
14. ``
15. `Permission is hereby granted, free of charge, to any person obtaining a copy`
16. `of this software and associated documentation files (the "Software"), to`
17. `deal in the Software without restriction, including without limitation the`
18. `rights to use, copy, modify, merge, publish, distribute, sublicense, and/or`
19. `sell copies of the Software, and to permit persons to whom the Software is`
20. `furnished to do so, subject to the following conditions:`
21. ``
22. `The above copyright notice and this permission notice shall be included in`
23. `all copies or substantial portions of the Software.`
24. ``
25. `THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR`
26. `IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,`
27. `FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE`
28. `AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER`
29. `LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING`
30. `FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS`
31. `IN THE SOFTWARE.`
32. ``
33. `"""`
34. `from __future__ import with_statement`
35. ``
36. ``